@@ -1,6 +1,7 @@
 # 자주 쓰는 간단한 유틸 함수
 import pandas as pd
 import numpy as np
+import math
 
 def df_to_dict_replace_nan(df: pd.DataFrame) -> list[dict]:
     # NaN → None으로 변환
@@ -22,4 +23,15 @@ def pretty_print(obj):
 
     data = convert(obj)
 
-    print(json.dumps(data, indent=2, ensure_ascii=False, default=json_util.default))
\ No newline at end of file
+    print(json.dumps(data, indent=2, ensure_ascii=False, default=json_util.default))
+
+
+def clean_nans(obj):
+    if isinstance(obj, float) and math.isnan(obj):
+        return None
+    elif isinstance(obj, dict):
+        return {k: clean_nans(v) for k, v in obj.items()}
+    elif isinstance(obj, list):
+        return [clean_nans(v) for v in obj]
+    else:
+        return obj
\ No newline at end of file
